pub struct StoneSocketUnlock {
pub item_type: ItemType,
pub socket: StoneSocketSlot,
pub unlock_chapter: i64,
}Expand description
When one socket opens. Sockets open gradually — one piece of gear at a time
— modelled on FlipSettings.unlock_chapter.
Fields
item_type: ItemTypesocket: StoneSocketSlotunlock_chapter: i64Trait Implementations
Sourceimpl Clone for StoneSocketUnlock
impl Clone for StoneSocketUnlock
Sourcefn clone(&self) -> StoneSocketUnlock
fn clone(&self) -> StoneSocketUnlock
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoneSocketUnlock
impl Debug for StoneSocketUnlock
Sourceimpl<'de> Deserialize<'de> for StoneSocketUnlock
impl<'de> Deserialize<'de> for StoneSocketUnlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<StoneSocketUnlock> for JsValuewhere
StoneSocketUnlock: Serialize,
impl From<StoneSocketUnlock> for JsValuewhere
StoneSocketUnlock: Serialize,
Sourcefn from(value: StoneSocketUnlock) -> Self
fn from(value: StoneSocketUnlock) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
impl FromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for StoneSocketUnlockwhere
StoneSocketUnlock: Serialize,
impl IntoWasmAbi for StoneSocketUnlockwhere
StoneSocketUnlock: Serialize,
Sourceimpl JsonSchema for StoneSocketUnlock
impl JsonSchema for StoneSocketUnlock
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for StoneSocketUnlockwhere
StoneSocketUnlock: Serialize,
impl OptionIntoWasmAbi for StoneSocketUnlockwhere
StoneSocketUnlock: Serialize,
Sourceimpl RefFromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<StoneSocketUnlock>
type Anchor = SelfOwner<StoneSocketUnlock>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for StoneSocketUnlock
impl Serialize for StoneSocketUnlock
Sourceimpl Tsify for StoneSocketUnlock
impl Tsify for StoneSocketUnlock
const DECL: &'static str = "/**\n * When one socket opens. Sockets open gradually \u{2014} one piece of gear at a time\n * \u{2014} modelled on `FlipSettings.unlock_chapter`.\n */\nexport interface StoneSocketUnlock {\n item_type: ItemType;\n socket: StoneSocketSlot;\n unlock_chapter: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for StoneSocketUnlockwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for StoneSocketUnlockwhere
StoneSocketUnlock: Serialize,
impl VectorIntoWasmAbi for StoneSocketUnlockwhere
StoneSocketUnlock: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for StoneSocketUnlock
impl WasmDescribeVector for StoneSocketUnlock
impl Copy for StoneSocketUnlock